@@ -55,6 +55,7 @@ SYNC_IMPORT_TYPES = [
     "title",
     "description",
     "favorite",
+    "location",
 ]
 SYNC_IMPORT_TYPES_ALL = ["all"] + SYNC_IMPORT_TYPES
 
@@ -374,11 +375,87 @@ def import_metadata_for_photo(
         # add photo to any new albums but do not remove from existing albums
         results += _update_albums_for_photo(photo, metadata, dry_run, verbose)
 
+    if "location" in set_:
+        # If --set use origin location in the destination photo
+        results += _set_location_for_photo(photo, metadata, dry_run, verbose)
+    elif "location" in merge:
+        # if --merge 
+        #   and property is set in the destination then no action is taken;
+        #   if property is not set in the destination but is set in the source,
+        #      then the value is copied to destination.
+        results += _merge_location_for_photo(photo, metadata, dry_run, verbose)
+
     results += _set_metadata_for_photo(photo, metadata, set_, dry_run, verbose)
     results += _merge_metadata_for_photo(photo, metadata, merge, dry_run, verbose)
 
     return results
 
+def _process_location_for_photo(
+    photo: PhotoInfo,
+    metadata: dict[str, Any],
+    dry_run: bool,
+    verbose: Callable[..., None],
+    merge: bool = False,
+) -> SyncResults:
+    """Set or merge location metadata for a photo."""
+    field = "location"
+    updated = False
+    results = SyncResults()
+    photo_ = photoscript.Photo(photo.uuid)
+
+    value = tuple(metadata.get(field, (None, None)))
+    before = getattr(photo, field, (None, None))
+
+    if merge:
+        if all(coord is None for coord in before):
+            if value != before:
+                updated = True
+                verbose(f"\tMerging {field} to {value} from {before}")
+                if not dry_run:
+                    set_photo_property(photo_, field, value)
+            else:
+                verbose(f"\tNothing to do for {field}", level=2)
+        else:
+            verbose(f"\tLocation already set. Nothing done for {field}", level=2)
+    else:
+        if value != before:
+            updated = True
+            verbose(f"\tSetting {field} to {value} from {before}")
+            if not dry_run:
+                set_photo_property(photo_, field, value)
+        else:
+            verbose(f"\tNothing to do for {field}", level=2)
+
+    results.add_result(
+        photo.uuid,
+        photo.original_filename,
+        photo.fingerprint,
+        field,
+        updated,
+        before,
+        value)
+    return results
+
+
+def _set_location_for_photo(
+    photo: PhotoInfo,
+    metadata: dict[str, Any],
+    dry_run: bool,
+    verbose: Callable[..., None],
+) -> SyncResults:
+    """Set location metadata 9even if (None, None) for a photo, if different."""
+    return _process_location_for_photo(photo, metadata, dry_run, verbose, merge=False)
+
+
+def _merge_location_for_photo(
+    photo: PhotoInfo,
+    metadata: dict[str, Any],
+    dry_run: bool,
+    verbose: Callable[..., None],
+) -> SyncResults:
+    """Merge location metadata for a photo if not already set."""
+    return _process_location_for_photo(photo, metadata, dry_run, verbose, merge=True)
+
 
 def _update_albums_for_photo(
     photo: PhotoInfo,
@@ -438,9 +515,12 @@ def _set_metadata_for_photo(
         if field == "albums":
             continue
 
+        if field == "location":
+            continue
+
         value = metadata[field]
         before = getattr(photo, field)
-
+    
         if isinstance(value, list):
             value = sorted(value)
         if isinstance(before, list):
@@ -480,6 +560,9 @@ def _merge_metadata_for_photo(
         if field == "albums":
             continue
 
+        if field == "location":
+            continue
+
         value = metadata[field]
         before = getattr(photo, field)
 
@@ -547,6 +630,8 @@ def set_photo_property(photo: photoscript.Photo, property: str, value: Any):
         raise ValueError(f"{property} must be a str, not {type(value)}")
     elif property == "favorite":
         value = bool(value)
+    elif property == "location":
+        value = (value[0], value[1])
     elif property not in {"title", "description", "favorite", "keywords"}:
         raise ValueError(f"Unknown property: {property}")
     setattr(photo, property, value)
