@@ -20,7 +20,7 @@ UUID_DICT = {
 
 NAMES_DICT = {"raw": "DSC03584.jpeg", "heic": "IMG_3092.jpeg"}
 
-UUID_LIVE_HEIC = "8EC216A2-0032-4934-BD3F-04C6259B3304"
+UUID_LIVE_HEIC = "03EE6CE2-20E6-489D-A149-A2EC7D11C70A"  # IMG_3259.heic
 NAMES_LIVE_HEIC = ["IMG_3259.jpeg", "IMG_3259.mov"]
 
 
